==> hs-gio-0.12.0_1.tbz: lib/ghc-7.0.3/cabal/gio-0.12.0/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.0
id: gio-0.12.0-16b466872ae517e5ff6adb9c03bc0e15

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: stable
homepage: http://www.haskell.org/gtk2hs/
package-url:
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/gio-0.12.0
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/gio-0.12.0
              /usr/local/lib
hs-libraries: HSgio-0.12.0
extra-libraries: gio-2.0 gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         glib-0.12.0-8ee4233c74a76a3c53a9d5252cb0d3ba
         haskell98-1.1.0.1-d297a29bdc63fd1be05662f1882b09e7
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/gio-0.12.0/html/gio.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/gio-0.12.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gio-0.12.2.tbz: lib/ghc-7.0.4/cabal/gio-0.12.2/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.2
id: gio-0.12.2-82f43877f6d09df7fc0bd481c5149f20

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/gio-0.12.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/gio-0.12.2
              /usr/local/lib
hs-libraries: HSgio-0.12.2
extra-libraries: gio-2.0 gobject-2.0 gmodule-2.0 gthread-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: array-0.3.0.2-ecfce597e0f16c4cd1df0e1d22fd66d4
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         glib-0.12.2-4ce526ce8b34c051fc6659d35733dff6
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/gio-0.12.2/html/gio.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/gio-0.12.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
